@@ -1,8 +1,9 @@
-// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
+// Copyright 2015 - 2025, GIBIS-UNIFESP and the wiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
+#include "elementeditor.h"
 #include "graphicelement.h"
 #include "scene.h"
 
@@ -213,3 +214,20 @@ private:
     Scene *m_scene;
     int m_newOutputSize;
 };
+
+class ToggleTruthTableOutputCommand : public QUndoCommand
+{
+    Q_DECLARE_TR_FUNCTIONS(ToggleTruthTableOutputCommand)
+
+public:
+    explicit ToggleTruthTableOutputCommand(GraphicElement *element, int pos, Scene *scene, ElementEditor *ElementEditor, QUndoCommand *parent = nullptr);
+
+    void redo() override;
+    void undo() override;
+
+private:
+    ElementEditor *m_elementeditor;
+    Scene *m_scene;
+    int m_id;
+    int m_pos;
+};
