@@ -1,4 +1,4 @@
-// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
+// Copyright 2015 - 2025, GIBIS-UNIFESP and the wiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "display_7.h"
@@ -10,11 +10,6 @@
 #include <QPainter>
 #include <QPixmap>
 
-namespace
-{
-    int id = qRegisterMetaType<Display7>();
-}
-
 Display7::Display7(QGraphicsItem *parent)
     : GraphicElement(ElementType::Display7, ElementGroup::Output, ":/output/counter/counter_on.svg", tr("7-SEGMENT DISPLAY"), tr("7-Segment Display"), 8, 8, 0, 0, parent)
 {
@@ -36,7 +31,7 @@ Display7::Display7(QGraphicsItem *parent)
     m_alternativeSkins = m_defaultSkins;
     setPixmap(0);
 
-    qCDebug(three) << tr("Allocating pixmaps.");
+    qCDebug(three) << "Allocating pixmaps.";
     a =  QVector<QPixmap>(5, m_defaultSkins.at(1));
     b =  QVector<QPixmap>(5, m_defaultSkins.at(2));
     c =  QVector<QPixmap>(5, m_defaultSkins.at(3));
@@ -46,7 +41,7 @@ Display7::Display7(QGraphicsItem *parent)
     g =  QVector<QPixmap>(5, m_defaultSkins.at(7));
     dp = QVector<QPixmap>(5, m_defaultSkins.at(8));
 
-    qCDebug(three) << tr("Converting segments to other colors.");
+    qCDebug(three) << "Converting segments to other colors.";
     convertAllColors(a);
     convertAllColors(b);
     convertAllColors(c);
@@ -109,7 +104,7 @@ void Display7::updatePortsProperties()
     inputPort(6)->setPos(64, 40);    inputPort(6)->setName("DP (" + tr("dot")         + ")");
     inputPort(7)->setPos(64, 56);    inputPort(7)->setName("C (" +  tr("lower right") + ")");
 
-    for (auto *in : qAsConst(m_inputPorts)) {
+    for (auto *in : std::as_const(m_inputPorts)) {
         in->setRequired(false);
         in->setDefaultStatus(Status::Inactive);
     }
@@ -166,7 +161,7 @@ void Display7::load(QDataStream &stream, QMap<quint64, QNEPort *> &portMap, cons
      */
 
     if (version < VERSION("1.6")) {
-        qCDebug(zero) << tr("Remapping inputs.");
+        qCDebug(zero) << "Remapping inputs.";
         QVector<int> order{2, 1, 4, 5, 0, 7, 3, 6};
         QVector<QNEInputPort *> aux = inputs();
 
@@ -179,7 +174,7 @@ void Display7::load(QDataStream &stream, QMap<quint64, QNEPort *> &portMap, cons
     }
 
     if (version < VERSION("1.7")) {
-        qCDebug(zero) << tr("Remapping inputs.");
+        qCDebug(zero) << "Remapping inputs.";
         QVector<int> order{2, 5, 4, 0, 7, 3, 6, 1};
         QVector<QNEInputPort *> aux = inputs();
 
