@@ -1,15 +1,10 @@
-// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
+// Copyright 2015 - 2025, GIBIS-UNIFESP and the wiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "nand.h"
 
 #include "globalproperties.h"
 
-namespace
-{
-    int id = qRegisterMetaType<Nand>();
-}
-
 Nand::Nand(QGraphicsItem *parent)
     : GraphicElement(ElementType::Nand, ElementGroup::Gate, ":/basic/nand.svg", tr("NAND"), tr("Nand"), 2, 8, 1, 1, parent)
 {
