@@ -189,9 +189,10 @@ void ElementEditor::contextMenu(QPoint screenPos, QGraphicsItem *itemAtMouse)
         }
 
         case ElementGroup::Output: {
-            if ((selectedElm->elementType() == ElementType::Display7) || (selectedElm->elementType() == ElementType::Display14)) {
+            if ((selectedElm->elementType() == ElementType::Display7) || (selectedElm->elementType() == ElementType::Display14) || (selectedElm->elementType() == ElementType::Display16)) {
                 addElementAction(submenuMorph, selectedElm, ElementType::Display7, m_hasSameType);
                 addElementAction(submenuMorph, selectedElm, ElementType::Display14, m_hasSameType);
+                addElementAction(submenuMorph, selectedElm, ElementType::Display16, m_hasSameType);
             } else {
                 addElementAction(submenuMorph, selectedElm, ElementType::Buzzer, m_hasSameType);
                 addElementAction(submenuMorph, selectedElm, ElementType::Led, m_hasSameType);
@@ -694,7 +695,7 @@ void ElementEditor::apply()
 
     QByteArray oldData;
     QDataStream stream(&oldData, QIODevice::WriteOnly);
-    Serialization::writeHeaderPanda(stream);
+    Serialization::writePandaHeader(stream);
 
     for (auto *elm : std::as_const(m_elements)) {
         elm->save(stream);
