@@ -1,4 +1,4 @@
-// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
+// Copyright 2015 - 2025, GIBIS-UNIFESP and the wiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "elementmapping.h"
@@ -13,9 +13,9 @@
 ElementMapping::ElementMapping(const QVector<GraphicElement *> &elements)
     : m_elements(elements)
 {
-    qCDebug(three) << tr("Generate Map.");
+    qCDebug(three) << "Generate Map.";
     generateMap();
-    qCDebug(three) << tr("Connect.");
+    qCDebug(three) << "Connect.";
     connectElements();
 }
 
@@ -27,10 +27,10 @@ ElementMapping::~ElementMapping()
 
 void ElementMapping::generateMap()
 {
-    for (auto *elm : qAsConst(m_elements)) {
+    for (auto *elm : std::as_const(m_elements)) {
         if (elm->elementType() == ElementType::IC) {
             auto *ic = qobject_cast<IC *>(elm);
-            m_logicElms.append(ic->generateMap()->m_logicElms);
+            m_logicElms.append(ic->generateMap());
             continue;
         }
 
@@ -40,14 +40,13 @@ void ElementMapping::generateMap()
 
 void ElementMapping::generateLogic(GraphicElement *elm)
 {
-    auto logic = ElementFactory::buildLogicElement(elm);
-    elm->setLogic(logic.get());
-    m_logicElms.append(logic);
+    m_logicElms.append(ElementFactory::buildLogicElement(elm));
+    elm->setLogic(m_logicElms.last().get());
 }
 
 void ElementMapping::connectElements()
 {
-    for (auto *elm : qAsConst(m_elements)) {
+    for (auto *elm : std::as_const(m_elements)) {
         for (auto *inputPort : elm->inputs()) {
             applyConnection(elm, inputPort);
         }
@@ -96,18 +95,18 @@ void ElementMapping::sort()
 
 void ElementMapping::sortLogicElements()
 {
-    for (auto logic : qAsConst(m_logicElms)) {
+    for (auto &logic : std::as_const(m_logicElms)) {
         logic->calculatePriority();
     }
 
     std::sort(m_logicElms.begin(), m_logicElms.end(), [](const auto &logic1, const auto &logic2) {
-        return *logic1 > *logic2;
+        return logic1->priority() > logic2->priority();
     });
 }
 
 void ElementMapping::validateElements()
 {
-    for (auto logic : qAsConst(m_logicElms)) {
+    for (auto &logic : std::as_const(m_logicElms)) {
         logic->validate();
     }
 }
