@@ -36,6 +36,11 @@ IC::IC(QGraphicsItem *parent)
     });
 }
 
+IC::~IC()
+{
+    delete mapping;
+}
+
 void IC::save(QDataStream &stream) const
 {
     GraphicElement::save(stream);
@@ -77,15 +82,13 @@ void IC::load(QDataStream &stream, QMap<quint64, QNEPort *> &portMap, const QVer
 
 void IC::copyFile()
 {
-    QFileInfo fileInfo;
-    fileInfo.setFile(GlobalProperties::currentDir, QFileInfo(m_file).fileName());
+    const QString srcPath = IC::srcPath_ + "/" + m_file;
+    const QString destPath = IC::destPath_ + "/" + m_file;
 
-    const QString srcFile = IC::path + "/" + m_file;
-    const QString destFile = GlobalProperties::currentDir + "/" + fileInfo.fileName();
-    QFile file;
+    QFile destFile;
 
-    if (!file.exists(destFile) && !file.copy(srcFile, destFile)) {
-        throw Pandaception(tr("Error copying file: ") + file.errorString());
+    if (!QFile::exists(destPath) && !destFile.copy(srcPath, destPath)) {
+        throw Pandaception(tr("Error copying file: ") + destFile.errorString());
     }
 }
 
@@ -152,7 +155,7 @@ void IC::loadFile(const QString &fileName)
     }
 
     QDataStream stream(&file);
-    QVersionNumber version = Serialization::readHeaderPanda(stream);
+    QVersionNumber version = Serialization::readPandaHeader(stream);
     Serialization::loadDolphinFileName(stream, version);
     Serialization::loadRect(stream, version);
 
@@ -178,10 +181,10 @@ void IC::loadFile(const QString &fileName)
     m_icOutputLabels = QVector<QString>(m_icOutputs.size());
     sortPorts(m_icInputs);
     sortPorts(m_icOutputs);
-    loadInputs();
-    loadOutputs();
     loadInputsLabels();
     loadOutputsLabels();
+    loadInputs();
+    loadOutputs();
 
     // ----------------------------------------------
 
@@ -343,7 +346,7 @@ LogicElement *IC::outputLogic(const int index)
 
 void IC::loadInputsLabels()
 {
-    for (int portIndex = 0; portIndex < inputSize(); ++portIndex) {
+    for (int portIndex = 0; portIndex < m_icInputs.size(); ++portIndex) {
         auto *inputPort = m_icInputs.at(portIndex);
         auto *elm = inputPort->graphicElement();
         QString lb = elm->label();
@@ -363,7 +366,7 @@ void IC::loadInputsLabels()
 
 void IC::loadOutputsLabels()
 {
-    for (int portIndex = 0; portIndex < outputSize(); ++portIndex) {
+    for (int portIndex = 0; portIndex < m_icOutputs.size(); ++portIndex) {
         auto *outputPort = m_icOutputs.at(portIndex);
         auto *elm = outputPort->graphicElement();
         QString label = elm->label();
@@ -381,41 +384,42 @@ void IC::loadOutputsLabels()
     }
 }
 
-const QVector<std::shared_ptr<LogicElement>> IC::generateMap() const
+const QVector<std::shared_ptr<LogicElement>> IC::generateMap()
 {
-    ElementMapping mapping(m_icElements);
-    return mapping.logicElms();
+    mapping = new ElementMapping(m_icElements);
+    return mapping->logicElms();
 }
 
 void IC::refresh()
 {
 }
 
-void IC::copyFiles(const QFileInfo &srcFile)
+void IC::copyFiles(const QFileInfo &srcPath, const QFileInfo &destPath)
 {
     IC::needToCopyFiles = true;
 
-    const QString destFile = GlobalProperties::currentDir + "/" + srcFile.fileName();
-    QFile file;
+    QFile destFile;
 
-    if (!file.exists(destFile) && !file.copy(srcFile.absoluteFilePath(), destFile)) {
-        throw Pandaception(tr("Error copying file: ") + file.errorString());
+    if (!QFile::exists(destPath.absoluteFilePath()) && !destFile.copy(srcPath.absoluteFilePath(), destPath.absoluteFilePath())) {
+        throw Pandaception(tr("Error copying file: ") + destFile.errorString());
     }
 
-    file.setFileName(destFile);
+    destFile.setFileName(destPath.absoluteFilePath());
 
-    if (!file.open(QIODevice::ReadOnly)) {
-        throw Pandaception(QObject::tr("Error opening file: ") + file.errorString());
+    if (!destFile.open(QIODevice::ReadOnly)) {
+        throw Pandaception(QObject::tr("Error opening file: ") + destFile.errorString());
     }
 
-    QDataStream stream(&file);
-    QVersionNumber version = Serialization::readHeaderPanda(stream);
+    QDataStream stream(&destFile);
+    QVersionNumber version = Serialization::readPandaHeader(stream);
     Serialization::loadDolphinFileName(stream, version);
     Serialization::loadRect(stream, version);
 
-    IC::path = srcFile.absolutePath();
+    IC::srcPath_ = srcPath.absolutePath();
+    IC::destPath_ = destPath.absolutePath();
     Serialization::deserialize(stream, {}, version);
 
     IC::needToCopyFiles = false;
-    IC::path.clear();
+    IC::srcPath_.clear();
+    IC::destPath_.clear();
 }
