@@ -17,12 +17,12 @@ class IC : public GraphicElement
 
 public:
     explicit IC(QGraphicsItem *parent = nullptr);
-    ~IC() override = default;
+    ~IC() override;
     IC(const IC &other) : IC(other.parentItem()) {}
 
-    static void copyFiles(const QFileInfo &srcFile);
+    static void copyFiles(const QFileInfo &srcPath, const QFileInfo &destPath);
 
-    const QVector<std::shared_ptr<LogicElement>> generateMap() const;
+    const QVector<std::shared_ptr<LogicElement>> generateMap();
     LogicElement *inputLogic(const int index);
     LogicElement *outputLogic(const int index);
     void load(QDataStream &stream, QMap<quint64, QNEPort *> &portMap, const QVersionNumber version) override;
@@ -37,8 +37,10 @@ protected:
 private:
     static bool comparePorts(QNEPort *port1, QNEPort *port2);
     static void sortPorts(QVector<QNEPort *> &map);
+
+    inline static QString destPath_;
+    inline static QString srcPath_;
     inline static bool needToCopyFiles = false;
-    inline static QString path;
 
     void copyFile();
     void generatePixmap();
@@ -49,6 +51,7 @@ private:
     void loadOutputs();
     void loadOutputsLabels();
 
+    ElementMapping *mapping = nullptr;
     QFileSystemWatcher m_fileWatcher;
     QString m_file;
     QVector<GraphicElement *> m_icElements;
