@@ -35,6 +35,12 @@
 #include <QTemporaryFile>
 #include <QTranslator>
 
+#include <QSvgRenderer>
+
+void ensureSvgUsage() {
+    QSvgRenderer dummy; // for macdeployqt to add libqsvg.dylib
+}
+
 #ifdef Q_OS_WASM
 #include <emscripten/emscripten.h>
 #endif
@@ -49,7 +55,7 @@ MainWindow::MainWindow(const QString &fileName, QWidget *parent)
     : QMainWindow(parent)
     , m_ui(new Ui::MainWindow)
 {
-    qCDebug(zero) << "wiRedPanda Version = " APP_VERSION " OR" << GlobalProperties::version;
+    qCDebug(zero) << "wiRedPanda Version = " APP_VERSION " OR " << GlobalProperties::version;
     m_ui->setupUi(this);
 
     qCDebug(zero) << "Settings fileName: " << Settings::fileName();
@@ -324,10 +330,10 @@ void MainWindow::aboutThisVersion()
            "To open old version projects containing ICs (or boxes), skins, and/or "
            "beWavedDolphin simulations, their files must be moved to the same directory "
            "as the main project file.\n"
-           "wiRedPanda " APP_VERSION " will automatically list all other .panda files located "
+           "wiRedPanda %1 will automatically list all other .panda files located "
            "in the same directory of the current project as ICs in the editor tab.\n"
            "You have to save new projects before accessing ICs and skins, or running "
-           "beWavedDolphin simulations."));
+           "beWavedDolphin simulations.").arg(APP_VERSION));
     msgBox.setWindowModality(Qt::WindowModal);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.setCheckBox(checkBox);
@@ -440,6 +446,10 @@ void MainWindow::on_actionOpen_triggered()
 
 void MainWindow::on_actionSave_triggered()
 {
+    if (!m_currentTab) {
+        return;
+    }
+
     // TODO: if current file is autosave ask for filename
 
     QString fileName = m_currentFile.absoluteFilePath();
@@ -461,13 +471,11 @@ void MainWindow::on_actionSave_triggered()
 
 void MainWindow::on_actionSaveAs_triggered()
 {
-    QString path;
-
-    if (!m_currentFile.fileName().isEmpty()) {
-        path = m_currentFile.absoluteFilePath();
+    if (!m_currentTab) {
+        return;
     }
 
-    QString fileName = QFileDialog::getSaveFileName(this, tr("Save File as ..."), path, tr("Panda files (*.panda)"));
+    QString fileName = QFileDialog::getSaveFileName(this, tr("Save File as ..."), m_currentFile.absoluteFilePath(), tr("Panda files (*.panda)"));
 
     if (fileName.isEmpty()) {
         return;
@@ -477,7 +485,9 @@ void MainWindow::on_actionSaveAs_triggered()
         fileName.append(".panda");
     }
 
-    save(fileName);
+    IC::copyFiles(QFileInfo(m_currentFile), QFileInfo(fileName));
+
+    loadPandaFile(fileName);
 }
 
 void MainWindow::on_actionAbout_triggered()
@@ -776,6 +786,11 @@ void MainWindow::connectTab()
     m_ui->actionZoomOut->setEnabled(m_currentTab->view()->canZoomOut());
 }
 
+WorkSpace *MainWindow::currentTab() const
+{
+    return m_currentTab;
+}
+
 void MainWindow::tabChanged(const int newTabIndex)
 {
     disconnectTab(); // disconnect previously selected tab
@@ -1120,6 +1135,7 @@ void MainWindow::on_actionExportToImage_triggered()
 
 void MainWindow::retranslateUi()
 {
+    ElementFactory::clearCache();
     m_ui->retranslateUi(this);
     m_ui->elementEditor->retranslateUi();
 
@@ -1256,7 +1272,7 @@ void MainWindow::populateMenu(QSpacerItem *spacer, const QStringList &names, QLa
 void MainWindow::populateLeftMenu()
 {
     m_ui->tabElements->setCurrentIndex(0);
-    populateMenu(m_ui->verticalSpacer_InOut, {"InputVcc", "InputGnd", "InputButton", "InputSwitch", "InputRotary", "Clock", "Led", "Display7", "Display14", "Buzzer", "AudioBox"}, m_ui->scrollAreaWidgetContents_InOut->layout());
+    populateMenu(m_ui->verticalSpacer_InOut, {"InputVcc", "InputGnd", "InputButton", "InputSwitch", "InputRotary", "Clock", "Led", "Display7", "Display14", "Display16", "Buzzer", "AudioBox"}, m_ui->scrollAreaWidgetContents_InOut->layout());
     populateMenu(m_ui->verticalSpacer_Gates, {"And", "Or", "Not", "Nand", "Nor", "Xor", "Xnor", "Node"}, m_ui->scrollAreaWidgetContents_Gates->layout());
     populateMenu(m_ui->verticalSpacer_Combinational, {"TruthTable", "Mux", "Demux"}, m_ui->scrollAreaWidgetContents_Combinational->layout());
     populateMenu(m_ui->verticalSpacer_Memory, {"DLatch", "SRLatch", "DFlipFlop", "JKFlipFlop", "TFlipFlop"}, m_ui->scrollAreaWidgetContents_Memory->layout());
@@ -1417,7 +1433,8 @@ void MainWindow::on_pushButtonAddIC_clicked()
     QMessageBox::information(this, tr("Info"), tr("Selected files (and their dependencies) will be copied to current file folder."));
 
     for (const auto &file : files) {
-        IC::copyFiles(QFileInfo(file));
+        QFileInfo destPath(GlobalProperties::currentDir + "/" + QFileInfo(file).fileName());
+        IC::copyFiles(QFileInfo(file), destPath);
     }
 
     updateICList();
