@@ -347,6 +347,7 @@ void Scene::prevMainPropShortcut()
                 element->setAudio(element->previousAudio());
             break;
 
+        case ElementType::Display16:
         case ElementType::Display14:
         case ElementType::Display7:
             if (element->hasColors())
@@ -614,7 +615,7 @@ void Scene::cloneDrag(const QPointF mousePos)
 
     QByteArray itemData;
     QDataStream stream(&itemData, QIODevice::WriteOnly);
-    Serialization::writeHeaderPanda(stream);
+    Serialization::writePandaHeader(stream);
     stream << mousePos;
     copy(selectedItems(), stream);
 
@@ -782,7 +783,7 @@ void Scene::copyAction()
 
     QByteArray itemData;
     QDataStream stream(&itemData, QIODevice::WriteOnly);
-    Serialization::writeHeaderPanda(stream);
+    Serialization::writePandaHeader(stream);
     copy(selectedItems(), stream);
 
     auto *mimeData = new QMimeData();
@@ -800,7 +801,7 @@ void Scene::cutAction()
 
     QByteArray itemData;
     QDataStream stream(&itemData, QIODevice::WriteOnly);
-    Serialization::writeHeaderPanda(stream);
+    Serialization::writePandaHeader(stream);
     cut(selectedItems(), stream);
 
     auto *mimeData = new QMimeData();
@@ -825,7 +826,7 @@ void Scene::pasteAction()
 
     if (!itemData.isEmpty()) {
         QDataStream stream(&itemData, QIODevice::ReadOnly);
-        QVersionNumber version = Serialization::readHeaderPanda(stream);
+        QVersionNumber version = Serialization::readPandaHeader(stream);
         paste(stream, version);
     }
 }
@@ -967,7 +968,7 @@ void Scene::dropEvent(QGraphicsSceneDragDropEvent *event)
         }
 
         QDataStream stream(&itemData, QIODevice::ReadOnly);
-        Serialization::readHeaderPanda(stream);
+        Serialization::readPandaHeader(stream);
 
         QPoint offset;      stream >> offset;
         ElementType type;   stream >> type;
@@ -1011,7 +1012,7 @@ void Scene::dropEvent(QGraphicsSceneDragDropEvent *event)
         }
 
         QDataStream stream(&itemData, QIODevice::ReadOnly);
-        QVersionNumber version = Serialization::readHeaderPanda(stream);
+        QVersionNumber version = Serialization::readPandaHeader(stream);
 
         QPointF offset; stream >> offset;
         QPointF ctr;    stream >> ctr;
@@ -1234,7 +1235,7 @@ void Scene::addItem(QMimeData *mimeData)
 {
     QByteArray itemData = mimeData->data("wpanda/x-dnditemdata");
     QDataStream stream(&itemData, QIODevice::ReadOnly);
-    Serialization::readHeaderPanda(stream);
+    Serialization::readPandaHeader(stream);
 
     QPoint offset;      stream >> offset;
     ElementType type;   stream >> type;
