@@ -13,6 +13,7 @@
 #include <QHBoxLayout>
 #include <QMessageBox>
 #include <QSaveFile>
+#include <QStandardPaths>
 #include <QTemporaryFile>
 
 WorkSpace::WorkSpace(QWidget *parent)
@@ -92,7 +93,7 @@ void WorkSpace::save(const QString &fileName)
     m_scene.setSceneRect(m_scene.itemsBoundingRect());
 
     QDataStream stream(&saveFile);
-    Serialization::writeHeaderPanda(stream);
+    Serialization::writePandaHeader(stream);
     save(stream);
 
     if (!saveFile.commit()) {
@@ -146,7 +147,7 @@ void WorkSpace::load(const QString &fileName)
     }
 
     QDataStream stream(&file);
-    QVersionNumber version = Serialization::readHeaderPanda(stream);
+    QVersionNumber version = Serialization::readPandaHeader(stream);
     load(stream, version);
 
     emit fileChanged(m_fileInfo);
@@ -204,7 +205,7 @@ QString WorkSpace::dolphinFileName()
 void WorkSpace::setAutosaveFileName()
 {
     qCDebug(zero) << "Defining autosave path.";
-    QDir autosavePath(QDir::currentPath() + "/autosaves");
+    QDir autosavePath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/autosaves");
 
     if (!autosavePath.exists()) {
         autosavePath.mkpath(autosavePath.absolutePath());
@@ -248,7 +249,7 @@ void WorkSpace::autosave()
 
     if (m_fileInfo.fileName().isEmpty()) {
         qCDebug(three) << "Default value not set yet.";
-        path.setPath(QDir::currentPath() + "/autosaves");
+        path.setPath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/autosaves");
 
         if (!path.exists()) {
             path.mkpath(path.absolutePath());
@@ -274,7 +275,7 @@ void WorkSpace::autosave()
 
     qCDebug(three) << "Writing to autosave file.";
     QDataStream stream(&m_autosaveFile);
-    Serialization::writeHeaderPanda(stream);
+    Serialization::writePandaHeader(stream);
     save(stream);
     m_autosaveFile.close();
 
