@@ -1,7 +1,8 @@
-// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
+// Copyright 2015 - 2025, GIBIS-UNIFESP and the wiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "common.h"
+#include "registertypes.h"
 #include "testcommands.h"
 #include "testelements.h"
 #include "testfiles.h"
@@ -14,11 +15,13 @@
 
 int main(int argc, char **argv)
 {
+    registerTypes();
+
     Comment::setVerbosity(-1);
 
     QApplication app(argc, argv);
     app.setOrganizationName("GIBIS-UNIFESP");
-    app.setApplicationName("WiRedPanda");
+    app.setApplicationName("wiRedPanda");
     app.setApplicationVersion(APP_VERSION);
 
     int status = 0;
